[prev in list] [next in list] [prev in thread] [next in thread] 

List:       kde-commits
Subject:    [ksnakeduel] /: Fix minor EBN issues
From:       Yuri Chornoivan <null () kde ! org>
Date:       2018-09-13 18:38:18
Message-ID: E1g0WVO-0001g4-0X () code ! kde ! org
[Download RAW message or body]

Git commit 48bd5f8534ac8c6c0a43cece31b0ea2432c64831 by Yuri Chornoivan.
Committed on 13/09/2018 at 18:38.
Pushed by yurchor into branch 'master'.

Fix minor EBN issues

M  +2    -1    ksnakeduelui.rc
M  +1    -1    ktron.cpp
M  +3    -3    tron.cpp
M  +4    -4    tron.h

https://commits.kde.org/ksnakeduel/48bd5f8534ac8c6c0a43cece31b0ea2432c64831

diff --git a/ksnakeduelui.rc b/ksnakeduelui.rc
index f942fde..2f05918 100644
--- a/ksnakeduelui.rc
+++ b/ksnakeduelui.rc
@@ -3,5 +3,6 @@
      version="4"
      xmlns="http://www.kde.org/standards/kxmlgui/1.0"
      xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-     xsi:schemaLocation="http://www.kde.org/standards/kxmlgui/1.0 \
http://www.kde.org/standards/kxmlgui/1.0/kxmlgui.xsd"> +     \
xsi:schemaLocation="http://www.kde.org/standards/kxmlgui/1.0 +                        \
http://www.kde.org/standards/kxmlgui/1.0/kxmlgui.xsd">  </gui>
diff --git a/ktron.cpp b/ktron.cpp
index 1000078..0b39657 100644
--- a/ktron.cpp
+++ b/ktron.cpp
@@ -55,7 +55,7 @@ public:
 };
 
 /**
- * Constuctor
+ * Constructor
  */
 KTron::KTron(QWidget *parent) : KXmlGuiWindow(parent, KDE_DEFAULT_WINDOWFLAGS) {
 	m_tron = new Tron(this);
diff --git a/tron.h b/tron.h
index 849613f..5493fb5 100644
--- a/tron.h
+++ b/tron.h
@@ -141,8 +141,8 @@ class Tron : public QWidget
 		// Key handling / movement
 		void switchKeyOn(int, KBAction::Action);
 		void switchKeyOff(int, KBAction::Action);
-		/** Check head to head collissions */
-		void checkHeadToHeadCollission();
+		/** Check head to head collisions */
+		void checkHeadToHeadCollision();
 		/** Helper for the doMove() function */
 		void movementHelper(bool onlyAcceleratedPlayers);
 		/** Tries to generate a new obstacle */
@@ -151,8 +151,8 @@ class Tron : public QWidget
 	private slots:
 		/**
 		* This is the main function of KTron.
-		* It checkes if an accelerator is pressed and than moves this player
-		* forward. Then it checkes if a crash occurred.
+		* It checks if an accelerator is pressed and than moves this player
+		* forward. Then it checks if a crash occurred.
 		* If no crash happen it moves both players forward and checks again
 		* if someone crashed.
 		*/


[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic
diff --git a/tron.cpp b/tron.cpp
index c9cada3..234388a 100644
--- a/tron.cpp
+++ b/tron.cpp
@@ -586,7 +586,7 @@ void Tron::movementHelper(bool onlyAcceleratedPlayers)
 	/* player collision check */
 	if (!players[1]->isAlive())
 	{
-		checkHeadToHeadCollission();
+		checkHeadToHeadCollision();
 	}
 
 	updatePixmap();
@@ -616,10 +616,10 @@ void Tron::movementHelper(bool onlyAcceleratedPlayers)
 	}
 }
 
-void Tron::checkHeadToHeadCollission()
+void Tron::checkHeadToHeadCollision()
 {
 	// As player 1 and player 2 move at the same time
 	// a head to head collission is possible
 	// but tough movement actually is done sequential
 	// we have to check back if player 1 should die when player 2 did so
 	// that's where this function comes in :)
@@ -616,10 +616,10 @@ void Tron::movementHelper(bool onlyAcceleratedPlayers)
 {
 	// As player 1 and player 2 move at the same time
-	// a head to head collission is possible
+	// a head to head collision is possible
 	// but tough movement actually is done sequential
 	// we have to check back if player 1 should die when player 2 did so